@@ -1,24 +1,23 @@
 #!/usr/bin/perl
 
-package X11::Connection::INETFH;
+package X11::Protocol::Connection::INETFH;
 
 # Copyright (C) 1997 Stephen McCamant. All rights reserved. This program
 # is free software; you can redistribute and/or modify it under the same
 # terms as Perl itself.
 
-use X11::Connection::FileHandle;
+use X11::Protocol::Connection::FileHandle;
 use FileHandle;
 use Socket;
 use Carp;
 use strict;
 use vars qw($VERSION @ISA);
 
-@ISA = ('X11::Connection::FileHandle');
+@ISA = ('X11::Protocol::Connection::FileHandle');
 
 $VERSION = 0.01;
 
-sub open
-  {
+sub open {
     my($pkg) = shift;
     my($host, $dispnum) = @_;
     my($sock) = new FileHandle;
@@ -28,19 +27,20 @@ sub open
       croak "Can't connect to display `$host:$dispnum': $!";
     $sock->autoflush(1);
     return bless \$sock, $pkg;
-  }
+}
 1;
 __END__
 
 =head1 NAME
 
-X11::Connection::INETFH - Perl module for FileHandle-based TCP/IP X11 connections
+X11::Protocol::Connection::INETFH - Perl module for FileHandle-based TCP/IP X11 connections
 
 =head1 SYNOPSIS
 
   use X11::Protocol;
-  use X11::Connection::INETFH;
-  $conn = X11::Connection::INETFH->open($host, $display_number);
+  use X11::Protocol::Connection::INETFH;
+  $conn = X11::Protocol::Connection::INETFH
+    ->open($host, $display_number);
   $x = X11::Protocol->new($conn); 
 
 =head1 DESCRIPTION
@@ -51,14 +51,14 @@ connection, using the FileHandle module.
 
 =head1 AUTHOR
 
-Stephen McCamant <alias@mcs.com>.
+Stephen McCamant <SMCCAM@cpan.org>.
 
 =head1 SEE ALSO
 
 L<perl(1)>,
 L<X11::Protocol>,
-L<X11::Connection::UNIXFH>,
-L<X11::Connection::FileHandle>, 
+L<X11::Protocol::Connection::UNIXFH>,
+L<X11::Protocol::Connection::FileHandle>, 
 L<FileHandle>.
 
 =cut
