@@ -42,12 +42,12 @@ my $font_frac = .6; # text fills 60% of the height of the progresss bar
 # so if you also have a corresponding Type 1 outline, that's the best
 # choice: 
 # (bitmaps for sizes 8, 10, 11, 12, 14, 17, 18, 20, 24, 25, and 34)
-my $fontname = "-adobe-helvetica-medium-r-normal--%d-*-*-*-*-*-iso8859-1";
+#my $fontname = "-adobe-helvetica-medium-r-normal--%d-*-*-*-*-*-iso8859-1";
 # (If you're using Debian Linux like me, you'll need to install the
 #  gsfonts and gsfonts-x11 packages to get the Type 1 versions. The
 #  outline isn't the genuine Adobe version; it's a free clone that
 #  can also be accessed directly (without Adobe's bitmaps) as)
-#my $fontname = "-urw-nimbus sans l-regular-r-normal--%d-*-*-*-*-*-iso8859-1";
+my $fontname = "-urw-nimbus sans l-regular-r-normal--%d-*-*-*-*-*-iso8859-1";
 # * Recent X releases also include some scalable fonts, though not any
 # sans-serif ones. In the following, adobe-utopia can be replaced by
 # adobe-courier, bitstream-courier, or bitstream-charter:
@@ -315,7 +315,7 @@ sub paint_shaded_text {
       if $text_shading_style;
     $X->PolyText8($drawable, $tl_gc, ($x, $y - 1), @$text);
     $X->PolyText8($drawable, $tl_gc, ($x - 1, $y), @$text);
-  
+
     $X->PolyText8($drawable, $bg_gc, ($x, $y), @$text);
 }
 
